﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using MindFusion.Scheduling;
using MindFusion.Scheduling.Wpf;

namespace WpfApplication232
{
	/// <summary>
	/// Interaction logic for Window1.xaml
	/// </summary>
	public partial class Window1 : Window
	{
		public Window1()
		{
			InitializeComponent();

			calendar1.CellPresenterCreating += new EventHandler<CellPresenterCreatingEventArgs>(calendar1_CellPresenterCreating);

			calendar1.BeginInit();

			MyResource r1 = new MyResource()
			{
				Name = "res #1",
				WorkIntervals = new int[] { 8, 12, 13, 18 },
			};

			MyResource r2 = new MyResource()
			{
				Name = "res #2",
				WorkIntervals = new int[] { 8, 13, 13, 18 },
			};

			calendar1.ItemResources.Add(r1);
			calendar1.ItemResources.Add(r2);
			calendar1.GroupType = GroupType.GroupByResources;

			calendar1.EndInit();
		}

		void calendar1_CellPresenterCreating(object sender, CellPresenterCreatingEventArgs e)
		{
			// We are using a custom cell presenter. The custom presenter provides a
			// CustomBackground property which we are using to supply background colors
			// for different cells. By default the CustomBackground binds to the
			// CellPresenter.Background, thus if no custom background is provided, the
			// cells will use the default background
			var presenter = new CustomCellPresenter(calendar1);

			bool even = calendar1.ItemResources.IndexOf(e.Resource) % 2 == 0;
			Brush weekTimeBrush = null;

			if (even)
			{
				if (e.EndTime - e.StartTime < TimeSpan.FromDays(1))
					presenter.CustomBackground = Brushes.LightSlateGray;

				weekTimeBrush = Brushes.LightSteelBlue;
			}
			else
			{
				weekTimeBrush = Brushes.LightGray;
			}

			var myResource = e.Resource as MyResource;
			for (int i = 0; i < myResource.WorkIntervals.Length; i += 2)
			{
				DateTime from = e.StartTime.Date.AddHours(myResource.WorkIntervals[i]);
				DateTime to = e.StartTime.Date.AddHours(myResource.WorkIntervals[i + 1]);

				if (from <= e.StartTime && e.EndTime <= to)
				{
					presenter.CustomBackground = weekTimeBrush;
					break;
				}
			}

			e.CellPresenter = presenter;
		}
	}

	/// <summary>
	/// A custom resource class which also specifies a set of work intervals.
	/// </summary>
	public class MyResource : Resource
	{
		/// <summary>
		/// Gets or sets the work intervals associated with this resource expressed
		/// as hours since the beginning of the day, e.g. 8, 12, 18, etc.
		/// </summary>
		public int[] WorkIntervals
		{
			get;
			set;
		}
	}

}
